summary refs log tree commit diff
path: root/synapse/handlers
diff options
context:
space:
mode:
authorErik Johnston <erik@matrix.org>2022-04-26 17:07:21 +0100
committerGitHub <noreply@github.com>2022-04-26 17:07:21 +0100
commitf59e3f4c900b3961e2b96592a67cd2f0821b00db (patch)
tree06407ee7ebadca9d531a01085c3696a95182f2db /synapse/handlers
parentComment out dodgy log-kv (#12554) (diff)
downloadsynapse-f59e3f4c900b3961e2b96592a67cd2f0821b00db.tar.xz
Mark remote device list updates as already handled (#12557)
Diffstat (limited to 'synapse/handlers')
-rw-r--r--synapse/handlers/device.py5
1 files changed, 3 insertions, 2 deletions
diff --git a/synapse/handlers/device.py b/synapse/handlers/device.py
index 319836da2b..a91b1ee4d5 100644
--- a/synapse/handlers/device.py
+++ b/synapse/handlers/device.py
@@ -505,8 +505,9 @@ class DeviceHandler(DeviceWorkerHandler):
             "device_list_key", position, users={user_id}, rooms=room_ids
         )
 
-        # We may need to do some processing asynchronously.
-        self._handle_new_device_update_async()
+        # We may need to do some processing asynchronously for local user IDs.
+        if self.hs.is_mine_id(user_id):
+            self._handle_new_device_update_async()
 
     async def notify_user_signature_update(
         self, from_user_id: str, user_ids: List[str]